@@ -35,7 +35,7 @@
 #include <bits/os_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCPP__ 20030804
+#define __GLIBCPP__ 20050503
 
 // This is necessary until GCC supports separate template compilation.
 #define _GLIBCPP_NO_TEMPLATE_EXPORT 1
@@ -869,7 +869,7 @@
 #define _GLIBCPP_HAVE_SYS_RESOURCE_H 1
 
 /* Define if you have the <sys/stat.h> header file.  */
-/* #undef _GLIBCPP_HAVE_SYS_STAT_H */
+#define _GLIBCPP_HAVE_SYS_STAT_H 1
 
 /* Define if you have the <sys/time.h> header file.  */
 #define _GLIBCPP_HAVE_SYS_TIME_H 1
@@ -893,7 +893,7 @@
 #define _GLIBCPP_PACKAGE "libstdc++"
 
 /* Version number of package */
-#define _GLIBCPP_VERSION "3.3.1"
+#define _GLIBCPP_VERSION "3.3.6"
 
 /* Define if the compiler is configured for setjmp/longjmp exceptions. */
 /* #undef _GLIBCPP_SJLJ_EXCEPTIONS */
